USE [master]
GO

SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

IF  EXISTS (SELECT name FROM sys.databases WHERE name = N'DWDemoSource')
DROP DATABASE [DWDemoSource]
GO

USE [master]
GO

CREATE DATABASE [DWDemoSource]
GO

USE [DWDemoSource]
GO

IF NOT EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N'[dbo].[SourceClaimCode]') AND type in (N'U'))
BEGIN
CREATE TABLE [dbo].[SourceClaimCode](
	[ClaimCodeKey] [nvarchar](4) NOT NULL,
	[Description] [ntext] NULL,
 CONSTRAINT [PK_SourceClaimCode] PRIMARY KEY CLUSTERED 
(
	[ClaimCodeKey] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]
END
GO

IF NOT EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N'[dbo].[SourceClient]') AND type in (N'U'))
BEGIN
CREATE TABLE [dbo].[SourceClient](
	[ClientId] [int] NOT NULL,
	[ClientBusinessKey] [nvarchar](20) NOT NULL,
	[FirstName] [nvarchar](50) NOT NULL,
	[MiddleName] [nvarchar](50) NULL,
	[LastName] [nvarchar](50) NULL,
	[AddressLine1] [nvarchar](120) NULL,
	[AddressLine2] [nvarchar](120) NULL,
	[BirthDate] [date] NULL,
	[Gender] [nvarchar](1) NULL,
	[YearlyIncome] [money] NULL,
	[TotalChildren] [tinyint] NULL,
	[DateFirstPolicy] [date] NULL,
	[CommuteDistance] [nvarchar](15) NULL,
	[City] [nvarchar](30) NULL,
	[StateProvinceCode] [nvarchar](3) NULL,
	[StateProvinceName] [nvarchar](50) NULL,
	[CountryRegionCode] [nvarchar](3) NULL,
	[PostalCode] [nvarchar](15) NULL
 CONSTRAINT [PK_SourceClient] PRIMARY KEY CLUSTERED 
(
	[ClientId] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
END
GO

IF NOT EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N'[dbo].[SourcePolicyType]') AND type in (N'U'))
BEGIN
CREATE TABLE [dbo].[SourcePolicyType](
	[PolicyTypeKey] [nvarchar](4) NOT NULL,
	[Description] [ntext] NULL,
 CONSTRAINT [PK_SourcePolicyType] PRIMARY KEY CLUSTERED 
(
	[PolicyTypeKey] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]
END
GO

IF NOT EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N'[dbo].[SourcePolicy]') AND type in (N'U'))
BEGIN
CREATE TABLE [dbo].[SourcePolicy](
	[PolicyKey] [nvarchar](20) NOT NULL,
	[ClientId] [int] NOT NULL,
	[Deductable] [money] NULL,
	[Maximum] [money] NULL,
	[PolicyTypeKey] [nvarchar](4) NOT NULL,
 CONSTRAINT [PK_FactPolicies] PRIMARY KEY CLUSTERED 
(
	[PolicyKey] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
END
GO

IF NOT EXISTS (SELECT * FROM sys.foreign_keys WHERE object_id = OBJECT_ID(N'[dbo].[FK_SourcePolicy_SourceClient]') AND parent_object_id = OBJECT_ID(N'[dbo].[SourcePolicy]'))
ALTER TABLE [dbo].[SourcePolicy]  WITH CHECK ADD  CONSTRAINT [FK_SourcePolicy_SourceClient] FOREIGN KEY([ClientId])
REFERENCES [dbo].[SourceClient] ([ClientId])
GO

IF  EXISTS (SELECT * FROM sys.foreign_keys WHERE object_id = OBJECT_ID(N'[dbo].[FK_SourcePolicy_SourceClient]') AND parent_object_id = OBJECT_ID(N'[dbo].[SourcePolicy]'))
ALTER TABLE [dbo].[SourcePolicy] CHECK CONSTRAINT [FK_SourcePolicy_SourceClient]
GO

IF NOT EXISTS (SELECT * FROM sys.foreign_keys WHERE object_id = OBJECT_ID(N'[dbo].[FK_SourcePolicy_SourcePolicyType]') AND parent_object_id = OBJECT_ID(N'[dbo].[SourcePolicy]'))
ALTER TABLE [dbo].[SourcePolicy]  WITH CHECK ADD  CONSTRAINT [FK_SourcePolicy_SourcePolicyType] FOREIGN KEY([PolicyTypeKey])
REFERENCES [dbo].[SourcePolicyType] ([PolicyTypeKey])
GO

IF  EXISTS (SELECT * FROM sys.foreign_keys WHERE object_id = OBJECT_ID(N'[dbo].[FK_SourcePolicy_SourcePolicyType]') AND parent_object_id = OBJECT_ID(N'[dbo].[SourcePolicy]'))
ALTER TABLE [dbo].[SourcePolicy] CHECK CONSTRAINT [FK_SourcePolicy_SourcePolicyType]
GO

---
--- Initial data
---

INSERT INTO [dbo].[SourcePolicyType]
           ([PolicyTypeKey]
           ,[Description])
     VALUES
           (N'AUTO', N'Automobile'),
           (N'BOAT', N'Boat'),
           (N'HOME', N'Home owner''s insurance'),
           (N'RENT', N'Rent''s insurance')
GO


INSERT INTO [dbo].[SourceClaimCode]
           ([ClaimCodeKey]
           ,[Description])
     VALUES
           (N'CCAC', N'Car accident, shared responsibility'),
           (N'CDAF', N'Car accident, driver at fault'),
           (N'HWAT', N'Home coverage, water damage')
GO

exec sp_changedbowner 'sa','REDMOND\mmasson'